@@ -20,11 +20,15 @@ from concurrent.futures import ThreadPoolExecutor
 __all__ = [
     "install",
     "fpcalc_bin",
+    "ffprobe_bin",
+    "ffmpeg_bin",
     "fpcalc_install",
     "exiv2_bin",
     "exiv2json_bin",
     "ipfs_bin",
     "ipfs_install",
+    "java_bin",
+    "tika_bin",
 ]
 
 BASE_VERSION = "1.0.0"
